@@ -66,12 +66,10 @@ def break_out_individuals_cpl(
   combined_df = pandas.concat([claimant_df, partner_df, landlord_df, aa2_df, aa3_df, aa4_df], axis=0, ignore_index=True) \
     .dropna(subset=['forename', 'surname', 'address_1', 'postcode'])
 
-  # stats
-  print(f"claimants: {len(claimant_df)}")
-  print(f"partners: {len(partner_df)}")
-  print(f"landlords: {len(landlord_df)}")
-  print(f"aa2: {len(aa2_df)}")
-  print(f"aa3: {len(aa3_df)}")
-  print(f"aa4: {len(aa4_df)}")
+  # write stats
+  for key in ['claimant', 'partner', 'landlord', 'aa2', 'aa3', 'aa4']:
+    subset = claimant_df[claimant_df['row_type'] == key]
+    print(f"{key}: {len(subset)}")
+  
   print(f"final tally {len(combined_df)} valid residents")
   return combined_df
\ No newline at end of file
